;; Generated package description from xah-fly-keys.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "xah-fly-keys" "28.11.20260414134011.0.20260414.141628" "ergonomic modal keybinding minor mode." '((emacs "28.3")) :commit "f09a66647bb80a310826f0f1b763b174433b2664" :maintainer '("Xah Lee" . "xah@xahlee.org") :keywords '("convenience" "vi" "vim" "ergoemacs" "keybinding") :url "http://xahlee.info/emacs/misc/xah-fly-keys.html")
